@@ -4,7 +4,7 @@ Main runners. Bootloads Sniffer class.
 from __future__ import print_function, absolute_import
 from optparse import OptionParser
 from sniffer.scanner import Scanner
-from sniffer.runner import Sniffer, ScentSniffer
+from sniffer.runner import ScentSniffer
 from sniffer.metadata import __version__
 import sys
 
@@ -13,7 +13,9 @@ colorama.init()
 
 __all__ = ['run', 'main']
 
-def run(sniffer_instance=None, wait_time=0.5, clear=True, args=(), debug=False):
+
+def run(sniffer_instance=None, wait_time=0.5, clear=True, args=(),
+        debug=False):
     """
     Runs the auto tester loop. Internally, the runner instanciates the sniffer_cls and
     scanner class.
@@ -42,7 +44,8 @@ def run(sniffer_instance=None, wait_time=0.5, clear=True, args=(), debug=False):
     sniffer_instance.observe_scanner(scanner)
     scanner.loop(wait_time)
 
-def main(sniffer_instance=None, test_args=(), progname=sys.argv[0], args=sys.argv[1:]):
+def main(sniffer_instance=None, test_args=(), progname=sys.argv[0],
+         args=sys.argv[1:]):
     """
     Runs the program. This is used when you want to run this program standalone.
 
@@ -55,16 +58,20 @@ def main(sniffer_instance=None, test_args=(), progname=sys.argv[0], args=sys.arg
     ``args``        Command line arguments. Defaults to sys.argv[1:]
     """
     parser = OptionParser(version="%prog " + __version__)
-    parser.add_option('-w', '--wait', dest="wait_time", metavar="TIME", default=0.5, type="float",
-                      help="Wait time, in seconds, before possibly rerunning tests. "
-                      "(default: %default)")
-    parser.add_option('--no-clear', dest="clear_on_run", default=True, action="store_false",
+    parser.add_option('-w', '--wait', dest="wait_time", metavar="TIME",
+                      default=0.5, type="float",
+                      help="Wait time, in seconds, before possibly rerunning"
+                      "tests. (default: %default)")
+    parser.add_option('--no-clear', dest="clear_on_run", default=True,
+                      action="store_false",
                       help="Disable the clearing of screen")
-    parser.add_option('--debug', dest="debug", default=False, action="store_true",
+    parser.add_option('--debug', dest="debug", default=False,
+                      action="store_true",
                       help="Enabled debugging output. (default: %default)")
-    parser.add_option('-x', '--test-arg', dest="test_args", default=[], action="append",
-                      help="Arguments to pass to nose (use multiple times to pass multiple "
-                      "arguments.)")
+    parser.add_option('-x', '--test-arg', dest="test_args", default=[],
+                      action="append",
+                      help="Arguments to pass to nose (use multiple times to "
+                      "pass multiple arguments.)")
     (options, args) = parser.parse_args(args)
     test_args = test_args + tuple(options.test_args)
 
@@ -73,7 +80,8 @@ def main(sniffer_instance=None, test_args=(), progname=sys.argv[0], args=sys.arg
         print("Test Args:", test_args)
     try:
         print("Starting watch...")
-        run(sniffer_instance, options.wait_time, options.clear_on_run, test_args, options.debug)
+        run(sniffer_instance, options.wait_time, options.clear_on_run,
+            test_args, options.debug)
     except KeyboardInterrupt:
         print("Good bye.")
     except Exception:
