@@ -10,13 +10,21 @@ from .base import BaseScanner
 import win32file
 import win32con
 import os
-import thread, Queue, time
+import threading
+import time
+import sys
+if sys.version_info[0] == 2:
+    import Queue as queue
+else:
+    import queue
 
 ACTIONS = {}
-for i, name in enumerate(('Created', 'Deleted', 'Updated', 'Renamed from', 'Renamed to')):
+for i, name in enumerate(('Created', 'Deleted', 'Updated', 'Renamed from',
+                          'Renamed to')):
     ACTIONS[i] = name
 FILE_LIST_DIR = 0x0001
 
+
 class PyWinScanner(BaseScanner):
     """
     Scanner built on PyWin32 (aka, Win32API).
@@ -24,8 +32,8 @@ class PyWinScanner(BaseScanner):
     def __init__(self, *args, **kwargs):
         super(PyWinScanner, self).__init__(*args, **kwargs)
         self._running = False
-        self._q = Queue.Queue(1)
-        
+        self._q = queue.Queue(1)
+
     def _get_handle(self, path):
         return win32file.CreateFile(
             path,                                                 # filename
@@ -39,9 +47,9 @@ class PyWinScanner(BaseScanner):
 
     def _get_changes_blocking(self, handle):
         result = win32file.ReadDirectoryChangesW(
-            handle, # directory handle
-            1024, # buffer len (return size)
-            True, # watch recursively
+            handle,  # directory handle
+            1024,    # buffer len (return size)
+            True,    # watch recursively
             # notify filters
             win32con.FILE_NOTIFY_CHANGE_FILE_NAME | # create/rename/delete files
             #win32con.FILE_NOTIFY_CHANGE_DIR_NAME | # create/rename/delete dirs
@@ -49,8 +57,8 @@ class PyWinScanner(BaseScanner):
             #win32con.FILE_NOTIFY_CHANGE_ATTRIBUTES |
             #win32con.FILE_NOTIFY_CHANGE_SIZE |
             #win32con.FILE_NOTIFY_CHANGE_SECURITY,
-            None, # overlapped structure (?)
-            None  # completion routine (async only)
+            None,  # overlapped structure (?)
+            None   # completion routine (async only)
         )
         self._q.put(result)
 
@@ -59,7 +67,8 @@ class PyWinScanner(BaseScanner):
       can interrupt (terminate) the main thread from the console.
     """
     def _get_changes(self, handle):
-        thread.start_new_thread(self._get_changes_blocking, (handle,))
+        threading.Thread(target=self._get_changes_blocking,
+                         args=(handle,)).start()
         while self._q.empty():
             time.sleep(0.1)
         return self._q.get()
@@ -78,7 +87,7 @@ class PyWinScanner(BaseScanner):
                     self.trigger_modified(fullpath)
                 elif action == 'Deleted':
                     self.trigger_deleted(fullpath)
-        
+
     def loop(self, sleep_time=None):
         self.log("Library of choice: PyWin32 (eww)")
         self.trigger_init()
